function Z = bipole(theta, alpha, a, radius, sigma, showbipole, dosymcrop)
%Z = bipole(alpha, a) Orientation selective bipole filter.
%   alpha: opening angle of bipole fan (for a=1)
%   a: sharpening of bipole fan (for a>1 sharper fan, effects opening, too)
%   theta: orientation of fan
%   radius: radius of fan
%   sigma: standard deviation of smoothing gaussian

if nargin < 6
  showbipole = 0; % default; showbipole = 1 to plot mask
end

if nargin < 7
  dosymcrop = 1; % default; symcrop = 0 to generate full mask
end

if showbipole == 1
  extra_scale = 1;
  bound_x = ceil(radius + extra_scale*sigma);
  bound_y = ceil(radius + extra_scale*sigma);
  circlemasksize = ceil(radius + extra_scale*sigma);
elseif showbipole == 0
  bound_x = radius;
  bound_y = radius;
  circlemasksize = radius;
else
  error('Flag ''showbipole'' must have value 0 or 1.')
end

x = -bound_x:bound_x;
y = bound_y:-1:-bound_y;
[X, Y] = meshgrid(x, y);

Xrot =  X*cos(theta) + Y*sin(theta);
Yrot = -X*sin(theta) + Y*cos(theta);

PHI = atan2(abs(Yrot), abs(Xrot));
PHI = PHI/alpha * pi/2;

PHI(find(PHI >= pi/2)) = pi/2;
% alternative more `math-like' formulation of `PHI(find(PHI>=pi/2)) = pi/2;' :
%% PHI = PHI - h(PHI-pi/2).*(PHI + pi/2);
D = cos(PHI).^a;

%%S = corrDn(circle(radius, ceil(radius+extra_scale*sigma)), gauss2(sigma, sigma), 'repeat');
%%S = corrDn(circle(radius, circlemasksize), gauss2(sigma, sigma), 'repeat');

S = correlate2(circle(radius, circlemasksize), gauss2(sigma));

if dosymcrop == 1
  Z = symcrop(intnorm(D.*S));
else
  Z = intnorm(D.*S);
end

%------------------------------------------------------------------------------
function y = h(x) % heaviside or step function
y = 0.5*(1 + sign(x));
