function evalsquare(contrastrange, efbmode)
% 
% CONTRASTRANGE can be 0.1 or 0.2.
% EFBMODE can be 'standard' for the standard model or 'efb' for the model
% using early feedback
%  
% Generate data to plot the inset figures in Fig. 16 ('standard') and
% Fig. 20 ('efb')
% 
% Example
%  
% evalsquare(0.1, 'efb')
%
% Thorsten Hansen 2008-04-03

if nargin < 2
  efbmode = 'standard';
end

%maxnoise = (0.9-(0.5+contrastrange/2))/3.5

switch contrastrange
case  0.1
  std_noise_arr = [0.01 0.02 0.05 0.1];
  minval = 0.45; maxval = 0.55;
  contrastrange_str = '01';
case 0.2
  std_noise_arr = [0.01 0.02 0.04 0.08];
  minval = 0.4; maxval = 0.6;
  contrastrange_str = '02';
otherwise
  error('unknown contrastrange')
end

Niterations = 12;

for sn = [1 length(std_noise_arr)] % just min and max noise
  
  %contrastrange
  %std_noise_arr(sn)
  
  I = input2d('noisy square', [minval maxval std_noise_arr(sn)]);
  switch efbmode
   case 'standard'
    [C W] = modellr(I, Niterations); 
    efbmode_str = '';
   case 'efb'
    [C W] = modellrefb(I, Niterations);
    efbmode_str = 'efb';
   otherwise
    error(['Wrong mode ''' efbmode'''.'])
   end
  switch sn
   case 1
    I1 = I; C1 = C; Wfinal1 = W(:,:,:,Niterations);
   case length(std_noise_arr)
    I2 = I; C2 = C; Wfinal2 = W(:,:,:,Niterations);
  end  
end

filename = ['res_noisy_square' efbmode_str '_c' contrastrange_str '.mat'];

if exist(filename) == 2
  disp(['Filename ''' filename ''' exists. ' ...
       'Type return to overwrite, CTRL-C to abort.'])
  pause
end
eval(['save ' filename  ' I1 C1 Wfinal1 I2 C2 Wfinal2'])




%subplot(2,3,1), imshow(revert(I1)), title('Input stimulus'), axis on, ticksoff
%subplot(2,3,2), imshowr(sum(C1,3), []), title('Complex cells')
%subplot(2,3,3), imshowr(sum(Wfinal1, 3), []), title('Long-range stage')

%subplot(2,3,4), imshow(revert(I2)), title('Input stimulus'), axis on, ticksoff
%subplot(2,3,5), imshowr(sum(C2,3), []), title('Complex cells')
%subplot(2,3,6), imshowr(sum(Wfinal2, 3), []), title('Long-range stage')

