function figevalscale

%
% run model
%
Niterations = 12; % number of recurrent interactions
scale = [1.5 2 3]; 
Nscales = length(scale);
if exist('res_noisy_square_scales.mat') ~= 2
  Omax = 4; % number of orientations
  I = input2d('noisy square');
  for i = 1:Nscales
    [C{i} W{i}] = modellr(I, Niterations, Omax, scale(i));
  end
  save res_noisy_square_scales C W
else 
  load res_noisy_square_scales
end
  


%
% plot
%
for i = 1:Nscales
  
  s = Nscales - i+1; % scales in reversed order 

  [r z] = saliencynsquare(C{s}, W{s});

  subplot(1, 3, i) 
  h = plot([0:Niterations], r, 'k');
  set(h, 'Linewidth', 2)
  hold on
  plot([0:Niterations], z, 'k')
  hold off

  
  fs = 10; % 12
  fs_text = fs; % 14
  set(gca, 'Fontsize', fs);
  setxaxis([0 12])
  set(gca, 'XTick', [0:2:12])
  axis([0 12 2 8])
  
  box off
  
  golden_ratio = (1 + sqrt(5))/2;
  dina4_ratio = sqrt(2);
  set(gca, 'PlotBoxAspectRatio', [dina4_ratio 1 1])
  %axis square
  
  if i == 2
    xlabel('Time (Number of recurrent cycles)')
  end
  if i == 1
    ylabel('Contour saliency')
  else
    yticksoff
  end
  
  title(['Scale ' num2str(scale(s))])
  if s == 1, z_xpos = 1; else, z_xpos = 10; end
  text(10, r(10)-0.5, 'r', ... 
       'HorizontalAlignment', 'Left', ...
       'FontSize', fs_text, ...
       'FontName', 'Times', ...
       'FontAngle', 'italic')
  text(z_xpos, z(10)+0.4, 'z', ... 
       'HorizontalAlignment', 'Left', ...
       'FontSize', fs_text, ...
       'FontName', 'Times', ...
       'FontAngle', 'italic')

  
end  
