function fignoisysquare(figno)
% fignoisysquare(4)

  
%
% get input
%
I = input2d('noisy square');

%
% run model
%
Niterations = 12; % number of recurrent interactions
if exist('res_noisy_square.mat') ~= 2
  [C, W] = modellr(I, Niterations);
  save res_noisy_square C W
else
  load res_noisy_square
end

Wfinal = W(:,:,:,Niterations);



switch figno
 case 4


  %
  % show results -- Fig. 4
  % 
  subplot(1,3,1), imshow(I), title('Input stimulus'), axis on, ticksoff
  subplot(1,3,2), imshowr(sum(C,3), []), title('Complex cells')
  subplot(1,3,3), imshowr(sum(Wfinal, 3), []), title('Long-range stage')
  
  
 case 5

  %
  % show results -- Fig. 5
  %
  
  norows = 9; % number of rows
  nocols = norows; % number of columns
  c = [97 97]; % center of upper left corner
  if mod(norows, 2) == 0
    c = c + 1;
  end
  ind1 = c(1)-floor(norows/2):c(1)-floor(norows/2)+norows-1;
  ind2 = c(2)-floor(nocols/2):c(2)-floor(nocols/2)+nocols-1;
  
  subplot(1,3,1), imshow(I), title('Input stimulus'), axis on, ticksoff
  drawrect(ind2(1), ind1(1), nocols, norows, 'w', 1);
  
  subplot(1,3,2), oquiver(C(ind1, ind2, :)), title('Complex cells')
  subplot(1,3,3), oquiver(Wfinal(ind1, ind2, :)), title('Long-range stage')
  
  
 case 11
  
  %
  % show results -- Fig. 11
  %

  fs = 8;
  
  % top edge cut out
  ind1 = 76:117; ind2 = 100:160;
  
  subplot(2,3,1)
  imshow(I(ind1, ind2)), title('Input stimulus I', 'FontSize', fs)
  axis on, ticksoff
  
  subplot(2,3,2)
  imshowr(sum(C(ind1, ind2, :),3), []), title('Complex cells C', 'FontSize', fs)
  
  timearray = [1 2 12];
  for i = 1:length(timearray)
    t = timearray(i);
    subplot(2, 3, 3+i)
    imshowr(sum(W(ind1, ind2, :, t), 3), [])
    if i == 1
      title(['Long range W(t = ' int2str(t) ')'], 'FontSize', fs)
    else
      title(['W(t = ' int2str(t) ')'], 'FontSize', fs)
    end
  end
  
  drawnow
  
  % move left & up
  Ncols = 3;
  Nrows = 2;
  for spno = [1 2 4 5 6]
    % spno
    subplot(Nrows,Ncols,spno)
    sprow = floor((spno - 1)/Ncols) + 1;
    spcol = mod(spno - 1 , Ncols) + 1;
    pos = get(gca, 'Position');
    if spcol > 1
      pos(1) = pos(1) - (spcol - 1)*0.05;
    end
    if sprow == 2
      pos(2) = pos(2) + 0.22;
    end
    set(gca, 'Position', pos)
    %drawnow, pause
  end

  
  
 otherwise
  error('Unsupported figure number.')
end

