function Y = conv2gauss(X, sigma)
%CONV2GAUSS  Separated 2-D convolution with gaussian.
%Y = CONV2GAUSS(X, SIGMA) Convolution is performed using separability of the
%    isotropic 2-D gaussian, i.e. instead of one 2-D convolution two 1-D 
%    convolutions with an 1-D gaussian are performed. 
%
%    For a mask of size e.g. 49 (SIGMA = 8) this function is about 17
%    times faster than 2-D convolution in space domain and about 4
%    times faster than 2-D convolution in frequency domain (on an
%    Sparc Ultra).
%
% Thorsten Hansen 2007-03-31
  
g = gauss(sigma);
% old 2001 version
%Y = corrDn(X, g, 'repeat');
%Y = corrDn(Y, g', 'repeat');

Y = convolve2(convolve2(X, g), g');
