function X = convolve2(I, F)
%CONVOLVE  2D convolution.
%   X = CONVOLVE2(I, F) returns the convolution of image I with the 
%   filter F using Neumann boundary conditions, i.e., replicating the 
%   values at the boundary of I. The resulting X has the same size as I.
%
%   See also conv2 and in the Image Processing Toolbox imfilter.
%Thorsten Hansen  2004-09-02
if exist('imfilter') 
    % use imfilter if it exists
    X = imfilter(I, F, 'replicate', 'conv');
else % use conv2 and manually replicate border using repmat
    sz = floor(size(F)/2);
    I = [repmat(I(:,1), 1, sz(2)) I repmat(I(:,end), 1, sz(2))];
    I = [repmat(I(1,:), sz(1), 1); I; repmat(I(end,:), sz(1), 1)];

    X = conv2(I, F, 'valid');
end