function X = correlate2(I, F)
%CORRELATE  2D correlation.
%   X = CORRELATE2(I, F) returns the correlation of image I with the
%   filter F using Neumann boundary conditions, i.e., replicating the
%   values at the boundary of I. The resulting X has the same size as I.
%
%   See also convolve2. 
%Thorsten Hansen  2008-02-26
if exist('imfilter')
    % use imfilter from the image processing toolbox if it exists
    % disp('use imfilter')
    X = imfilter(I, F, 'replicate', 'corr');
else % use xcorr2 and manually replicate border using repmat
    sz = floor(size(F)/2)
    % replicate border
    I = [repmat(I(:,1), 1, sz(2)) I repmat(I(:,end), 1, sz(2))];
    I = [repmat(I(1,:), sz(1), 1); I; repmat(I(end,:), sz(1), 1)];
    
    X = cropborder(xcorr2(I, F), 2*sz);
end
