function z = dog2(sigma_c, sigma_s)
%DOG2 2-D difference of gaussians.
%       DOG22(S1, S2) is a matrix of a discretized difference of 2-D 
%       gaussians with standard deviation S1 (center) and S2 (surround).
%       The surrounding gaussian is subtracted from the center gaussian.

precision = 3;

bound_x = precision * ceil(sigma_s);
bound_y = bound_x;

x = (-bound_x : bound_x);
y = (-bound_y : bound_y);

[X, Y] = meshgrid(x, y);


g_c = 1/(2*pi * sigma_c * sigma_c) ...
        * exp(-0.5 * (X.^2 / sigma_c^2 + Y.^2 / sigma_c^2));
g_c = intnorm(g_c);

g_s = 1/(2*pi * sigma_s * sigma_s) ...
        * exp(-0.5 * (X.^2 / sigma_s^2 + Y.^2 / sigma_s^2));
g_s = intnorm(g_s);

z = g_c - g_s;

% alternative implementations....
%
% z = 1/(2*pi*sigma_c^2) * exp(-0.5 * (X.^2 + Y.^2) / sigma_c^2) ...
%     - 1/(2*pi*sigma_s^2) * exp(-0.5 * (X.^2 + Y.^2) / sigma_s^2);
%
% rho = sigma_s / sigma_c;
% z = 1/(2*pi*sigma_c^2) * ...
%         (exp(-0.5 * (X.^2 + Y.^2) / sigma_c^2) ...
%         - (1 / rho^2) * exp(-0.5 * (X.^2 + Y.^2) / rho^2 / sigma_c^2));

