function z = gauss2r(sigma_x, sigma_y, theta, m_x, m_y)
%GAUSS2R 2-D rotated gaussian.
%       GAUSS2(SX, SY, THETA, MX, MY) is a matrix of a rotated, discretized 
%       2-D gaussian with standard deviation SX in x-direction, SY in 
%       y-direction and offset MX, MY in x- and y-direction. SX and SY given 
%       *before* rotation, THETA given in rad.
%       Matrix size (M, N) is determined by SX and SY.

precision = 3;

bound_x = precision * sigma_x + abs(m_x);
bound_y = precision * sigma_y + abs(m_y);

bound_x_rot = ceil(abs(cos(theta)*bound_x) + abs(sin(theta)*bound_y));
bound_y_rot = ceil(abs(sin(theta)*bound_x) + abs(cos(theta)*bound_y));

x = (-bound_x_rot : bound_x_rot);
y = fliplr(-bound_y_rot : bound_y_rot);

[X, Y] = meshgrid(x, y);

%z = 1/(2*pi * sigma_x * sigma_y) ...
%        * exp(-0.5 * ((X .* cos(theta) - Y .* sin(theta)).^2 / sigma_x^2 ...
%                      + (X .* sin(theta) + Y .* cos(theta)).^2 / sigma_y^2));
%


z = 1/(2*pi * sigma_x * sigma_y) ...
        * exp(-0.5 * ((X .* cos(theta) + Y .* sin(theta) - m_x).^2 ...
                                                               / sigma_x^2 ...
                      + (- X .* sin(theta) + Y .* cos(theta) - m_y).^2 ...
                                                               / sigma_y^2));
z = intnorm(z);
