function y = gausso(sigma, itheta, Omax)
% GAUSSO  1-D Gaussian for orientation weighting.
%   Y = GAUSS(SIGMA, ITHETA, OMAX). 1-D Gaussian with OMAX entries, standard
%   deviation SIGMA. Mean at orientation ITHETA in {1, 2, ... OMAX}.


if mod(Omax, 2) == 0 
  x = (-Omax/2+1:Omax/2);
else
  x = (-floor(Omax/2):floor(Omax/2));
end

y = exp(-0.5 * (x.^2/sigma^2)); % gaussian weighting 
y = y ./sum(y);  % normalize


% reorder y so that the maximum value is at position ITHETA.
isplit = mod(Omax/2 - itheta, Omax) + 1;
y = y([isplit:Omax 1:isplit-1]);

