function I = map01(I, method, m)
%MAPO1  Maps array to the range [0;1]
%
%   I = MAP01(I, METHOD) scales input array I to fit within the range [0,1].
%      METHOD can be 
%      'full': in this case, the full range is covered, i.e., the 
%              minumum of I is mapped to 0 and the maximum element to 1.
%      'centerzero': in this case, the midvalue of the original range 
%              is mapped to 0.5 and the value with the largest distance
%              from the midvalue is mapped to 0 if its value is smaller
%              than the midvalue, else to 1.
%              If I has both positive and negative elements,
%              map01(I, 'centerzero') maps 0 to 0.5, 
%              i.e., "zero is centered at at 0.5".
%
%(c) Thorsten Hansen 2003-02-27

if nargin == 1
  method = 'full';
end

switch method
 case 'full'
  %I = I - gmin(I);
  %I = I/gmax(I);
  I = (I- min(I(:)))/max(I(:)-min(I(:)));
 case 'centerzero'
  m = max(abs(min(I(:))), abs(max(I(:))));
  I = 0.5 + I/(2*m);
 case 'center05'
  if nargin == 2  
    m = max(abs(minmax(I) - 0.5));
    % m = max(abs(gmin(I)-0.5), abs(gmax(I)-0.5));
  end
  I = (I - 0.5)/(m/0.5) + 0.5;
 case 'mean'
  if nargin < 3
    m = mean(I); % not intended for images, but for two columns, where the
               % first represents the min, the second the max for a set
               % of images; see bsdimages 'minmaxDKL'
  end
  m1 = m(1); m2 = m(2);
  I = (I - m1)/(m2 - m1);
otherwise
  error(['unknown method ' method])
end
