function Y = setsubmat(X, S, si, sj)
%SETSUBMAT(X, S, xi, yi) assigns the matrix S to matrix X, so that the 
%   center of S is positioned at xi, xj. The size of X must be larger than X.


%   matrix coordinate system
%  
%     o----------> 
%     | 
%     |         j 
%     |
%     |
%     |
%     v  i
%


error(nargchk(1, 4, nargin));
if nargin<2, error('There must be at least two arguments'); end

[sizeXi, sizeXj] = size(X);
[sizeSi, sizeSj] = size(S);

% insert centered no position specified
if nargin<3, si = floor(sizeXi/2); end
if nargin<4, sj = floor(sizeXj/2); end

% check if size X is larger than S
if (sizeXi < sizeSi) | (sizeXj < sizeSj)
  error('Matrix (arg 1) must be larger than submatrix S (arg 2)')
end

% check if center position lay within dimensions of X
if (si > sizeXi) | (sj > sizeXj)  
  error('Matrix (first arg) must be larger than center positions (arg 3, 4)')
end

% compute indices of X where S has to be inserted
if mod(sizeXi,2)==1 & mod(sizeXj,2)==1 & mod(sizeSi,2)==1 & mod(sizeSj,2)==1
  % odd X and S
  top = si - floor(sizeSi/2 - 1);
  left = sj - floor(sizeSj/2 - 1);
else
  top = si - floor(sizeSi/2 - 0.5);
  left = sj - floor(sizeSj/2 - 0.5);
end
bottom = top + sizeSi -1;
right = left + sizeSj -1;



% check if indices lay within X
if (top <= 0) | (left <= 0) | (bottom > sizeXi) | (right > sizeXj)
  error('submatrix at center point exceeds matrix dimensions')
end

% assign submatrix
Y = X;
Y(top:bottom, left:right) =  S;
