function I = input2d(stimulusname, argvec);
%INPUT2D  Generate input stimuli for the model.
%
% Thorsten Hansen 2008-04-07
imagedir = '/home/hansen/images/';

switch stimulusname
case 'square'
  if nargin == 1, bg = 0.4; fg = 0.5; 
  else
    bg = argvec(1); fg = argvec(2);
  end
  
  xsize = 256;
  ysize = xsize;
  ssize = xsize/4;
  background = bg*ones(ysize, xsize);
  foreground = fg*ones(ssize, ssize);
  I = setsubmat(background, foreground);
case {'noisy square' 'nsquare'}
  % I = input('square');
  % I = imnoise(I, 'gaussian', 0.0, 0.01);
  % instead of the above two lines, create the image once and than use 
  %   always this image (the same noise for every run)
  if nargin == 1
    load('./stimuli/I_noisy_square.mat')
    I = I_noisy_square;
  else
    I = input2d('square', [argvec(1:2)]);
    I = imnoise(I, 'gaussian', 0.0, argvec(3)^2);
  end
case 'step'
  I = 0.4*ones(128);
  I(:, 65:128) = 0.5;
case 'hbar'
  width = argvec(1);
  I = 0.4*ones(256);
  bar = 0.5*ones(width, 80);
  I = setsubmat(I, bar);
case 'cross'
  width = argvec(1);
  I = 0.4*ones(256);
  bar = 0.5*ones(width, 80);
  I = setsubmat(I, bar);
  I = setsubmat(I, bar');
case {'kapadia1', 'kapadia2', 'kapadia3', 'kapadia4', 'kapadia5'}
  stimulidir = './stimuli/';
  fullfilename = [stimulidir stimulusname '.tif'];
  I = autocrop(getlayer(im2double(imread(fullfilename)), 1));
  % set border pixels to 1
  I(1:end, 1) = 1; I(1:end, end) = 1; I(1, 1:end) = 1;I(end, 1:end) = 1;
case 'hexagon'
  I = imread('/home/hansen/vision/doc/general/corner/fig/hexagon.tif');
  I = double(I)/255;
  I = 1 - sum(I,3)/3;
  I = setsubmat(zeros(256), autocrop(I));
case 'attneavecat'
  I = double(imread('/home/hansen/vision/images/attneavecat.tif'))/255;
case 'banana'
  %I = double(imread('/home/hansen/fromniall/vision/images/fruits/banana1.tif'))/255;
  I = im2double(imread('./stimuli/banana1.tif'));
  I = I(100:400, 30:600); % crop 
case 'potato'
  %I = double(imread('/home/hansen/fromniall/vision/images/fruits/sweet_potato1.tif'))...
  %      /255;
  I = im2double(imread('./stimuli/sweet_potato1.tif'));
case 'bananaedges'
  I = double(imread('/home/hansen/vision/images/pat-banana.tif'))/255;
case 'tree'
  I = double(imread('/home/vision/images/tree.tif'))/255;
case 'ellipse'
  I = double(imread(...
      '/home/hansen/vision/images/ellipse.tif'))/255;
case 'noisy ellipse'
  I = double(imread([imagedir 'ellipse_noise.tif']))/255;
case 'stairs'
  I = double(imread([imagedir 'stairs.tif']))/255;
case 'lena'
  I = double(imread(...
      '/home/hansen/vision/images/lena256.tif'))/255;
case 'cube'
  I = double(imread([imagedir 'cube-red.tif']))/255;
  I = cropborder(I, 5);
case {'small blue cube', 'cubesmall'}
  %I = double(imread(...
  %    '/home/hansen/fromniall/vision/images/cube-blue-small.tif'))/255;
  I = im2double(imread('./stimuli/cube-blue-small.tif'));
  I = cutborder(I, 5);
case {'small red cube', 'cubesmallrot'}
  I = double(imread(...
      '/home/hansen/vision/images/cube-red-small.tif'))/255;
  I = cutborder(I, 5);
case 'cells'  
  %I = im2double(imread(...
  %    '/home/hansen/fromniall/vision/images/cellsimp.tif'));
  I = im2double(imread('./stimuli/cellsimp.tif'));
case 'cellcomp'  
  I = double(imread(...
      '/home/hansen/vision/images/cellcomp.tif'))/255;
case 'cornertest'
  I = double(pgmRead([imagedir 'corner_test.pgm']))/255;
case 'mokhtarianlab'
  I = double(pgmRead([imagedir 'mokhtarian_lab.pgm']))/255;
  I = I([29:end],:); % delete black stripe on top
  I = I(1:256, 1:256); % crop 256 x 256 subimage
case 'plantlog'
  I = readiml([imagedir 'imk01601.imc']);
  I = map01(log(I));
case 'plant1'
  I = readiml([imagedir 'imk01601.imc']);
  % crop corner
  x = round(1415.71);   y = round(110.21);
  imsize = 128; 
  ih = imsize/2;
  I = map01(I(y-ih:y+ih-1, x-ih:x+ih-1)); 
case 'banana pattern'
  I = double(imread(...
      '/home/hansen/vision/images/pat-banana.tif'));
case 'circle pattern'
  I = double(imread(...
      '/home/hansen/vision/images/pat-circle.tif'));
case 'icirclelayers'
  I = double(imread(...
      '/home/hansen/vision/images/FGJunc1.tif'))/255;
case 'isquarelayers'
  I = double(imread(...
      '/home/hansen/vision/images/FGJunc2.tif'))/255;
 case 'licircle'
  I = im2double(imread('./stimuli/Li1999Fig6C.tif'));
  
%
% junctions
%
case {'l_junction', 'ljunction'}
  if nargin == 1
    I = 0.4*ones(128);
    I(65:128, 65:128) = 0.5*ones(64);
  else
    %I = genjunc(128, [0 rad(10) rad(10)+rad(argvec(1))], [0.6 0.4 0.6]);
    %
    I = genjunc(256, [0 rad(argvec(1))], [0.4 0.6]);
    I = imrotate(I, 20);
    c1 = round(size(I,1)/2); c2 = round(size(I,2)/2);
    I = I(c1-64:c1+64-1, c2-64+2:c2+64-1+2); 
  end 
case {'psi_junction', 'psijunction'}
  if nargin == 1
    I = input2d('step');
    for i=1:64
      I(1:i, i) = 0.3*ones(i, 1);
    end
    for i=65:128
      I(1:65-(i-64), i) = 0.6*ones(65-(i-64), 1);
    end
  else
    disp('psijunction with argument')
    I = genjunc(256, [0 rad(argvec(1))], [1 0]);
    I = -0.2*I - 0.2*flipud(I) + 0.6;
    I = I + [0.1*ones(128, 256); zeros(128, 256)];
    I = imrotate(I, 20);
    c1 = round(size(I,1)/2); c2 = round(size(I,2)/2);
    I = I(c1-64:c1+64-1, c2-64+2:c2+64-1+2);    
  end
case 'step'
  I = 0.4*ones(128);
  I(:, 65:128) = 0.5;
case {'t_junction', 'tjunction'}
  I = 0.5*ones(128);
  I(65:128, 1:64) = 0.4*ones(64);
  I(65:128, 65:128) = 0.6*ones(64);
case {'w_junction', 'wjunction'}
  if nargin == 1
    I = 0.4*ones(128);
    for i=1:64
      I(1:i, i) = 0.6*ones(i, 1);
    end
    for i=65:128
      I(1:65-(i-64), i) = 0.5*ones(65-(i-64), 1);
    end
  else
    disp('wjunction with argument')
    %I = genjunc(128, [rad(argvec(1))], [0.4 0.5 0.6]); 
    I = genjunc(256, [0 rad(argvec(1))], [1 0]);
    I = -0.1*I - 0.2*flipud(I) + 0.6;
    I = imrotate(I, 20);
    c1 = round(size(I,1)/2); c2 = round(size(I,2)/2);
    I = I(c1-64:c1+64-1, c2-64+2:c2+64-1+2);
  end
case 'wjunction5'
  I = genjunc(128, [rad(0), rad(5)], [1 0]);
  I = -0.1*I - 0.2*flipud(I) + 0.6;
case 'wjunction10'
  I = genjunc(128, [rad(0), rad(10)], [1 0]);
  I = -0.1*I - 0.2*flipud(I) + 0.6;
case 'wjunction15'
  I = genjunc(128, [rad(0), rad(15)], [1 0]);
  I = -0.1*I - 0.2*flipud(I) + 0.6;
case {'x_junction', 'xjunction'}
  I = [0.3*ones(64) 0.4*ones(64); 0.5*ones(64) 0.6*ones(64)];
case {'y_junction', 'yjunction'}
  I = input2d('step');
  for i=1:64
    I(1:i, i) = 0.6*ones(i, 1);
  end
  for i=65:128
    I(1:65-(i-64), i) = 0.6*ones(65-(i-64), 1);
  end
case 'y_junction-wb' % with border
  I = input2d('y_junction');
  I = setsubmat(0.7*ones(200), I);
  I = setsubmat(0.8*ones(256), I);
case 'y_junction-wb-wc' % with border, white center
  I = input2d('y_junction-wb');
  I = setsubmat(I, ones(10));
%
%
otherwise
  error(['unknown stimulusname: ' stimulusname])
end


