function makefig(arg1, display_eps)
%MAKEFIG  Generate Figures for  paper
%
%Example:
%
% makefig(1)  % Generate first figure
% makefig('all') % Generate all figures
% makefig(2, 1) % Generate second figure and shows eps using 'display'
%  
%
% Thorsten Hansen 2008-04-07

%  
% == Coding to generate the figures ==
%  
% If figures change place, just move or comment out the respective
% code fragment w/o need to edit numbers.
%
% To generate a color figure, use 
%
%     generatecolfigure(CODE)
%  
% where CODE is the string which generates the figure (usually a
% function).
%
% For b/w figures use
%  
%     generatebwfig(CODE)
%
% The order in the code determines the number of the figure. Re-ordering the
% figures in the manuscript just requires a re-ordering in makefig.m and
% running makefig('all').
%  
% Thorsten Hansen 2008-04-02
%



%
% initializations
%
if ~strcmp(iptgetpref('ImshowInitialMagnification') , 'fit')
  disp('Setting iptsetpref(''ImshowInitialMagnification'', ''fit'')')
  iptsetpref('ImshowInitialMagnification', 'fit')
end

% convert '5a' into 5 and '5b' into 6 and '7' into 7
if isstr(arg1) % to specify subfigure
  if ~strcmp(arg1, 'all')
    arg1
    if isalpha(arg1(end))
      arg1 = double(lower(arg1(end))) - double('a') + sscanf(arg1(1:end-1), '%d');
    else
      error('Strings can only be used with subfigure label, e.g, ''5a''. ')
      arg1 = sscanf(arg1, '%d');
      % to make this work, we need to store a table of figno figlabel
      % generated on the fly...
    end
  end
end

% switch to control whether generated eps is displayed using 'display'
% from ImageMagick  
global display_eps_flag

if nargin > 1
  display_eps_flag = display_eps;
else
  display_eps_flag = 0;
end

global figno, figno = arg1;
global figcount, figcount = 1; % running trough all figures, including subfigures
global figlabel, figlabel = 1; % the label determining the file under
                               % which the figure is stored.
                               % figcount and figlabel differ only if you
                               % use subfigures
global subfigcount, subfigcount = 0;
global figurename
global colorfig
global dstdir
dstdir = '/home/hansen/doc/papers/contour/fig/'; % *** edit directory here
dstdir = './figures/';


if exist(dstdir) == 0 
  disp(['Try to create ' dstdir '...'])
  [success, message, messageid] = mkdir(dstdir);
  if success
    disp('... Success.')
  else
    disp(['... ' message])
  end
end

  
%style = 'default' ;% *** edit style here
style = 'JOV';

switch style
 case 'JOV'
  manuscriptprefix = 'JOV-00736-2007-'; % *** edit number here
  colorprefix = '4c';
  bwprefix = 'bw';
  figprefix = 'f';
 otherwise % 'default'
  manuscriptprefix = '';
  colorprefix = '';
  bwprefix = '';
  figprefix = 'Fig';
end

global colorfigprefix
colorfigprefix = [manuscriptprefix colorprefix figprefix];
global bwfigprefix
bwfigprefix = [manuscriptprefix bwprefix figprefix];


%
% now the figures
%


% Fig. 1
generatebwfig('figdummy') % overview of model stages
% cp /home/hansen/doc/diss/fig/contour/stagesrfplain.fig
% /home/hansen/doc/papers/contour/fig/JOV-00736-2007-bwf001.fig

% Fig. 2
generatebwfig('figbipole')

% Fig. 3
generatebwfig('figgauss3', [0.5  8.10 20.44  6.05])
         % Paper position: Left  Top  Width  Height

% Fig. 4
generatebwfig('fignoisysquare(4)')

% Fig. 5
generatebwfig('fignoisysquare(5)')

% Fig. 6
generatebwfig('figkapadia')

% Fig. 7
generatebwfig('figcells')

% Fig. 8
generatebwfig('figcube')

% Fig. 9
generatebwfig('figbanana')

% Fig. 10
generatebwfig('figpotato') 

% Fig. 11
generatebwfig('fignoisysquare(11)')

% Fig. 12
generatebwfig('figsaliency') 

% Fig. 13
generatebwfig('figevalscale') 

% Fig. 14
generatebwfig('figosignif') 

% Fig. 15
generatebwfig('figosignifsynth') 

% Fig. 16
generatebwfig('figosignif_contrastnoise') 

% Fig. 17
generatebwfig('figdummy') % overview of model stages, early feedback

% Fig. 18
generatebwfig('fignoisysquareefb')

% Fig. 19
generatebwfig('figsaliencyefb')

% Fig. 20
generatebwfig('figosignifefb_contrastnoise')





  

% ------------------------------------------------------------------------------
function generatecolfig_subfig1(code, paperposition)
% ------------------------------------------------------------------------------
global colorfigprefix
global figlabel
global subfigcount

if subfigcount ~= 0
  figlabel = figlabel + subfigcount - 1;
end
subfigcount = 1; 
if nargin < 2
  generatethisfigure(colorfigprefix, code)
else
  generatethisfigure(colorfigprefix, code, paperposition)
end


% ------------------------------------------------------------------------------
function generatecolfig_subfig(code, paperposition)
% ------------------------------------------------------------------------------
global colorfigprefix
global subfigcount, subfigcount = subfigcount + 1;

if nargin < 2
  generatethisfigure(colorfigprefix, code)
else
  generatethisfigure(colorfigprefix, code, paperposition)
end


% ------------------------------------------------------------------------------
function generatecolfig(code, paperposition)
% ------------------------------------------------------------------------------
global colorfigprefix
global figlabel
global subfigcount

global colorfig
colorfig = 1;

if subfigcount ~= 0
  figlabel = figlabel + subfigcount - 1;
  subfigcount = 0; % explicitely set subfigcount to zero 
end

if nargin < 2
  generatethisfigure(colorfigprefix, code)
else
  generatethisfigure(colorfigprefix, code, paperposition)
end


%
% same for bw fig
%

% ------------------------------------------------------------------------------
function generatebwfig_subfig1(code, paperposition)
% ------------------------------------------------------------------------------
global bwfigprefix
global figlabel
global subfigcount

if subfigcount ~= 0
  figlabel = figlabel + subfigcount - 1;
end
subfigcount = 1; 
if nargin < 2
  generatethisfigure(bwfigprefix, code)
else
  generatethisfigure(bwfigprefix, code, paperposition)
end


% ------------------------------------------------------------------------------
function generatebwfig_subfig(code, paperposition)
% ------------------------------------------------------------------------------
global bwfigprefix
global subfigcount, subfigcount = subfigcount + 1;

if nargin < 2
  generatethisfigure(bwfigprefix, code)
else
  generatethisfigure(bwfigprefix, code, paperposition)
end


% ------------------------------------------------------------------------------
function generatebwfig(code, paperposition)
% ------------------------------------------------------------------------------
global bwfigprefix
global subfigcount, subfigcount = 0;

global colorfig
colorfig = 0;
if nargin < 2
  generatethisfigure(bwfigprefix, code)
else
  generatethisfigure(bwfigprefix, code, paperposition)
end



% ------------------------------------------------------------------------------
function generatethisfigure(prefix, code, paperposition)
% ------------------------------------------------------------------------------
% generate figure if the figno equals the current figcount
% increment global variable figcount
global figno
global figcount
global figlabel
global subfigcount
global dstdir
global figurename
global bwfigprefix
global colorfigprefix
global colorfig
global display_eps_flag

if strcmp(figno, 'all') || (figno == figcount)
  clf % get rid of previous stuff in figure

  
  if nargin > 2
    set(gcf, 'PaperPositionMode', 'manual');
    set(gcf, 'PaperUnits', 'centimeters');
    default_pos = get(gcf, 'PaperPosition'); 
    set(gcf, 'PaperPosition', paperposition);
  end
    
  figurename = [dstdir prefix sprintf('%03d', figlabel) '.eps'];
  if subfigcount ~= 0
    %figcount_subfig = figcount - subfigcount + 1;
    %figurename = [dstdir prefix sprintf('%03d', figcount_subfig) '.eps'];
    subfiglabel = char(double('a') + subfigcount - 1);
    figurename = strrep(figurename, '.eps', [subfiglabel '.eps']);
    % subfigcount = subfigcount + 1;
    % do not increment figlabel for subfigures!
  end
  
  disp(['generate Fig. ' int2str(figcount) ' in ' figurename])
  if strcmp(code, 'figdummy')
    disp(['Figure not created within Matlab. ' ...
          'Just used as place holder in makefig. This is ok.'])
  else
    eval(code)
    if colorfig
      % disp('print color figure')
      eval(['print -depsc ' figurename]);
    else
      % disp('print bw figure')
      eval(['print -deps ' figurename]);
    end
    
    if display_eps_flag
      % display to verify... what you see in matlab is not always what you
      % get as .eps 
      disp('')
      disp('Quit display to finish makefig.')
      system(['display ' figurename]);
    end
  end
  
  if nargin > 2
    % restore defaults for next figure
    set(gcf, 'PaperPosition', default_pos);  
  end  
end


figcount = figcount + 1;
if subfigcount == 0
  figlabel = figlabel + 1;
end
