function [C, Wall] = modellrefb(I, runs)
%
% long-range model with early feedback
%

if runs == 0
  C = 0; Wall = 0; % just to define a dummy return value
end

feedback = 'DOI'; % 'early LGN', 'DOI'

%
% feedback loop
%
for i = 1:runs

  fprintf('.') % progress dot

  %----------------------------------------
  % LGN on and off cells
  %----------------------------------------
  
  sigma_c         = 1.00;
  sigma_s         = 3.00;
  K = correlate2(I, dog2(sigma_c, sigma_s));
  
   if strcmp(feedback, 'early LGN')
     if i == 1, Wsum = K; else Wsum = sum(W, 3); end
  end

  if strcmp(feedback, 'early LGN') & i > 1
    strdisp('*** early feedback')
    delta_K = 2;
    K_on = hwrect(K + delta_K*Wsum);
    K_off = hwrect(-(K - delta_K*Wsum));
  else
    K_on = hwrect(K);
    K_off = hwrect(-K);
  end
  
  strdisp(['K_on: ' rangestr(K_on)])
  strdisp(['K_off: ' rangestr(K_on)])

  %----------------------------------------
  % simple cells
  %----------------------------------------
  O_max = 4; % number of orientations % ***changed*** 8
  %    strdisp(['**** o_max: ' int2str(O_max) ' ***'])
  sigma_y = 1.00;
  sigma_x = 3.00;
  tau = 3.00;

  if strcmp(feedback, 'DOI') & i > 1
    strdisp('*** DOI feedback new new')
    Xi = 2 - osignif(W);
    %Xi = 2 - hwrect((osignif(W) - 0.3)/(0.8 - 0.3));
  else
    Xi = 0;
  end
  [S_ld, S_dl] = simplecells(K_on, K_off, O_max, Xi);
  %strdisp(['simple ld: min ' num2str(min(S_ld(:)))]); 
  strdisp(['         : max ' num2str(max(S_ld(:)))]); 
  %strdisp(['       dl: min ' num2str(min(S_dl(:)))]); 
  strdisp(['         : max ' num2str(max(S_dl(:)))]); 
  
  %----------------------------------------
  % complex cells
  %----------------------------------------
  C = S_ld + S_dl;
  %strdisp(['complex min ' num2str(min(C(:)))]);
  strdisp(['        max ' num2str(max(C(:)))]);

  %----------------------------------------
  % combination
  %----------------------------------------
  alpha_V = 0.2;
  beta_V = 10;
  delta_V = 2;

  if i == 1 | strcmp(feedback, 'early LGN')
    strdisp('*** W set to C') 
    W = C; 
  end
  
  net_theta = C + delta_V*W; 
  strdisp(['            max ' num2str(max(net_theta(:)))]);
  
  V = beta_V * net_theta ./ (alpha_V + net_theta); % Eq. 7
  strdisp(['          max ' num2str(max(V(:)))]);

  
  %----------------------------------------
  % long-range interaction
  %----------------------------------------
  W = longrange(V);

  %strdisp(['W(t = ' int2str(i) ') min ' num2str(min2(W))]);
  strdisp(['          max ' num2str(max(W(:)))]);

  Wall(:,:,:,i) = W;
end
fprintf('\n')
