%------------------------------------------------------------------------------
function [r z] = saliencynsquare(C, W)
%------------------------------------------------------------------------------
% Saliency for predefined regions of the noisy square.

Niterations = size(W, 4);

% 
% Define indices for contour and background
%  
% contour indices for the noisy square
% left border
indy{1} =  112:145; indx{1} =  96:97;
% top border
indy{2} = 96:97; indx{2} = 112:145;
% right border:
indy{3} = 112:145; indx{3} = 160:161;
% bottom border:
indy{4} = 160:161; indx{4} = 112:145;

% background indices
indx_back = 256/2-8:256/2+8-1;
indy_back = 256/2-8:256/2+8-1;


% first consider summed activity:
% C = sum(C, 3);
% W = squeeze(sum(W, 3));

% alternatively: consider max activity (a la Li)
C = max(C, [], 3);
W = squeeze(max(W, [], 3));


% foreground
for p=1:size(indx,2)
  x_fg(p,1) = mean2(C(indy{p}, indx{p}));
  for i=1:Niterations
    x_fg(p,i+1) = mean2(W(indy{p}, indx{p}, i));
  end
end
x_fg = mean(x_fg);

% background
x_bg(1) = mean2(C(indy_back, indx_back));
std_bg(1) = std2(C(indy_back, indx_back));
for i=1:Niterations
  x_bg(i+1) = mean2(W(indy_back, indx_back, i));
  std_bg(i+1) = std2(W(indy_back, indx_back, i));
end


% whole image as `background'
x_all(1) = mean2(C);
std_all(1) = std2(C);
for i=1:Niterations
  x_all(i+1) = mean2(W(:, :, i));
  std_all(i+1) = std2(W(:, :, i));
end

r = x_fg./x_all;
z = (x_fg - x_all)./std_all;

