function [S_ld, S_dl] = simplecells(K_on, K_off, Omax, Xi)
%SIMPLECELLS  Model simple cell responses.
%
% Thorsten Hansen 2008-04-08
  
sigma_y = 1.00;
sigma_x = 3.00;
tau = 3.00;

for i=1:Omax % for all orientations
  % compute Gaussian filters for left and right input 
  m_x = 0;
  m_y = tau;
  theta = (i-1)*pi/Omax;
  G_r = gauss2rsum(sigma_x, sigma_y, m_x, -m_y, theta, 1);
  G_l = gauss2rsum(sigma_x, sigma_y, m_x, m_y, theta, 1);

  if nargin < 4
    % convolve each contrast with each Gaussian (Eq. 2)
    R_on_l  = hwrect(correlate2(K_on, G_l));  
    R_on_r  = hwrect(correlate2(K_on, G_r));
    R_off_l = hwrect(correlate2(K_off, G_l));  
    R_off_r = hwrect(correlate2(K_off, G_r));
  else
   % convolve each contrast with each Gaussian after dominating opponent
   % interaction (Eq. 21) 
   R_on_l  = hwrect(correlate2(K_on - Xi.*K_off, G_l));  
   R_on_r  = hwrect(correlate2(K_on - Xi.*K_off, G_r));
   R_off_l = hwrect(correlate2(K_off - Xi.*K_on, G_l));  
   R_off_r = hwrect(correlate2(K_off - Xi.*K_on, G_r));
  end
  
  % linear interaction (Eq. 3)
  S_ld_1 = R_on_l  + R_off_r;
  S_dl_1 = R_off_l + R_on_r;

  % spatial competition with anisotropic blurring
  Gr = gauss2r(sigma_x, sigma_y, theta, 0, 0);
  S_ld_i = hwrect(correlate2(S_ld_1 - S_dl_1, Gr)); % (Eq. 4)
  S_dl_i = hwrect(correlate2(S_dl_1 - S_ld_1, Gr));

  S_ld(:,:,i) = S_ld_i;
  S_dl(:,:,i) = S_dl_i;
end

